import { main } from '@/api'
import request from '@/utils/require'

// 进销存
export function selectJxcbbList(data) {
    return request({
        url: `${main}/client/ftjcbbb/selectJxcbbList?pageNum=${data.pageNum}&pageSize=${data.pageSize}`,
        method: 'post',
        data: data,
    })
}
//详情
export function selectJxcbbDetail(hzqs) {
    return request({
        url: `${main}/client/ftjcbbb/selectJxcbbDetail?hzqs=${hzqs}`,
        method: 'post',
        data: {},
    })
}
//生成详情
export function selectJxcbbDetailByHzqs(hzqs) {
    return request({
        url: `${main}/client/ftjcbbb/selectJxcbbDetailByHzqs?hzqs=${hzqs}`,
        method: 'post',
        data: {},
    })
}
//生成-保存
export function insertJxcbb(data) {
    return request({
        url: `${main}/client/ftjcbbb/insertJxcbb`,
        method: 'post',
        data: data,
    })
}
//删除
export function deleteJxcbb(id) {
    return request({
        url: `${main}/client/ftjcbbb/deleteJxcbb?id=${id}`,
        method: 'post',
        data: {},
    })
}


// 库存年限表
export function selectKcnfbList(data) {
    return request({
        url: `${main}/client/ftjcbbb/selectKcnfbList?pageNum=${data.pageNum}&pageSize=${data.pageSize}`,
        method: 'post',
        data: data,
    })
}
//详情
export function selectKcnfbDetail(hzqs) {
    return request({
        url: `${main}/client/ftjcbbb/selectKcnfbDetail?hzqs=${hzqs}`,
        method: 'post',
        data: {},
    })
}
//生成详情
export function selectKcnfbDetailByHzqs(hzqs) {
    return request({
        url: `${main}/client/ftjcbbb/selectKcnfbDetailByHzqs?hzqs=${hzqs}`,
        method: 'post',
        data: {},
    })
}
//生成-保存
export function insertKcnfb(data) {
    return request({
        url: `${main}/client/ftjcbbb/insertKcnfb`,
        method: 'post',
        data: data,
    })
}
//删除
export function deleteKcnfb(id) {
    return request({
        url: `${main}/client/ftjcbbb/deleteKcnfb?id=${id}`,
        method: 'post',
        data: {},
    })
}


// 库存分布表
export function selectKcfbList(data) {
    return request({
        url: `${main}/client/ftjcbbb/selectKcfbList?pageNum=${data.pageNum}&pageSize=${data.pageSize}`,
        method: 'post',
        data: data,
    })
}
//详情
export function selectKcfbDetail(hzqs) {
    return request({
        url: `${main}/client/ftjcbbb/selectKcfbDetail?hzqs=${hzqs}`,
        method: 'post',
        data: {},
    })
}
//生成详情
export function selectKcfbDetailByHzqs(hzqs) {
    return request({
        url: `${main}/client/ftjcbbb/selectKcfbDetailByHzqs?hzqs=${hzqs}`,
        method: 'post',
        data: {},
    })
}
//生成-保存
export function insertKcfb(data) {
    return request({
        url: `${main}/client/ftjcbbb/insertKcfb`,
        method: 'post',
        data: data,
    })
}
//删除
export function deleteKcfb(id) {
    return request({
        url: `${main}/client/ftjcbbb/deleteKcfb?id=${id}`,
        method: 'post',
        data: {},
    })
}